@@ -1,4 +1,6 @@
 #include "openbox/actions.h"
+#include "openbox/stacking.h"
+#include "openbox/window.h"
 #include "openbox/event.h"
 #include "openbox/focus_cycle.h"
 #include "openbox/openbox.h"
@@ -12,6 +14,8 @@ typedef struct {
     gboolean desktop_windows;
     gboolean all_desktops;
     gboolean forward;
+    gboolean bar;
+    gboolean raise;
     GSList *actions;
 } Options;
 
@@ -32,7 +36,7 @@ static void     i_cancel_func(gpointer options);
 
 static void     end_cycle(gboolean cancel, guint state, Options *o);
 
-void action_cyclewindows_startup()
+void action_cyclewindows_startup(void)
 {
     actions_register("NextWindow", setup_forward_func, free_func,
                      run_func, i_input_func, i_cancel_func);
@@ -47,11 +51,16 @@ static gpointer setup_func(ObParseInst *i, xmlDocPtr doc, xmlNodePtr node)
 
     o = g_new0(Options, 1);
     o->dialog = TRUE;
+    o->bar = TRUE;
 
     if ((n = parse_find_node("linear", node)))
         o->linear = parse_bool(doc, n);
     if ((n = parse_find_node("dialog", node)))
         o->dialog = parse_bool(doc, n);
+    if ((n = parse_find_node("bar", node)))
+        o->bar = parse_bool(doc, n);
+    if ((n = parse_find_node("raise", node)))
+        o->raise = parse_bool(doc, n);
     if ((n = parse_find_node("panels", node)))
         o->dock_windows = parse_bool(doc, n);
     if ((n = parse_find_node("desktop", node)))
@@ -112,17 +121,22 @@ static void free_func(gpointer options)
 static gboolean run_func(ObActionsData *data, gpointer options)
 {
     Options *o = options;
+    struct _ObClient *ft;
 
-    focus_cycle(o->forward,
-                o->all_desktops,
-                o->dock_windows,
-                o->desktop_windows,
-                o->linear,
-                TRUE,
-                o->dialog,
-                FALSE, FALSE);
+    ft = focus_cycle(o->forward,
+                     o->all_desktops,
+                     o->dock_windows,
+                     o->desktop_windows,
+                     o->linear,
+                     TRUE,
+                     o->bar,
+                     o->dialog,
+                     FALSE, FALSE);
     cycling = TRUE;
 
+    stacking_restore();
+    if (o->raise && ft) stacking_temp_raise(CLIENT_AS_WINDOW(ft));
+
     return TRUE;
 }
 
@@ -175,6 +189,7 @@ static void end_cycle(gboolean cancel, guint state, Options *o)
                      o->desktop_windows,
                      o->linear,
                      TRUE,
+                     o->bar,
                      o->dialog,
                      TRUE, cancel);
     cycling = FALSE;
@@ -182,4 +197,6 @@ static void end_cycle(gboolean cancel, guint state, Options *o)
     if (ft)
         actions_run_acts(o->actions, OB_USER_ACTION_KEYBOARD_KEY,
                          state, -1, -1, 0, OB_FRAME_CONTEXT_NONE, ft);
+
+    stacking_restore();
 }
