@@ -60,7 +60,7 @@ static gpointer setup_send_down_func(ObParseInst *i, xmlDocPtr doc,
                                      xmlNodePtr node);
 static gboolean run_func(ObActionsData *data, gpointer options);
 
-void action_desktop_startup()
+void action_desktop_startup(void)
 {
     actions_register("DesktopLast", setup_go_last_func, g_free,
                      run_func, NULL, NULL);
@@ -283,12 +283,14 @@ static gboolean run_func(ObActionsData *data, gpointer options)
     if (d < screen_num_desktops && d != screen_desktop) {
         gboolean go = TRUE;
 
+        actions_client_move(data, TRUE);
         if (o->send && data->client && client_normal(data->client)) {
             client_set_desktop(data->client, d, o->follow, FALSE);
             go = o->follow;
         }
 
         if (go) screen_set_desktop(d, TRUE);
+        actions_client_move(data, FALSE);
     }
     return FALSE;
 }
