@@ -4,6 +4,10 @@
 #include "openbox/screen.h"
 #include "gettext.h"
 
+#ifdef HAVE_STDLIB_H
+#  include <stdlib.h>
+#endif
+
 typedef struct {
     gchar   *cmd;
     gboolean sn;
@@ -23,7 +27,7 @@ static gboolean i_input_func(guint initial_state,
 static void     i_cancel_func(gpointer options);
 */
 
-void action_execute_startup()
+void action_execute_startup(void)
 {
     actions_register("Execute",
                      setup_func,
@@ -104,6 +108,7 @@ static gboolean run_func(ObActionsData *data, gpointer options)
             program = g_path_get_basename(argv[0]);
             /* sets up the environment */
             sn_setup_spawn_environment(program, o->sn_name, o->sn_icon,
+                                       o->sn_wmclass,
                                        /* launch it on the current desktop */
                                        screen_desktop);
         }
