@@ -3,7 +3,7 @@
 
 static gboolean run_func(ObActionsData *data, gpointer options);
 
-void action_focustobottom_startup()
+void action_focustobottom_startup(void)
 {
     actions_register("FocusToBottom", NULL, NULL, run_func, NULL, NULL);
 }
