@@ -3,7 +3,7 @@
 
 static gboolean run_func_toggle(ObActionsData *data, gpointer options);
 
-void action_fullscreen_startup()
+void action_fullscreen_startup(void)
 {
     actions_register("ToggleFullscreen", NULL, NULL, run_func_toggle,
                      NULL, NULL);
