@@ -9,7 +9,7 @@ static gpointer setup_func(ObParseInst *i, xmlDocPtr doc, xmlNodePtr node);
 static void     free_func(gpointer options);
 static gboolean run_func(ObActionsData *data, gpointer options);
 
-void action_restart_startup()
+void action_restart_startup(void)
 {
     actions_register("Restart",
                      setup_func,
