@@ -22,6 +22,7 @@
 #include "menuframe.h"
 #include "screen.h"
 #include "client.h"
+#include "client_list_combined_menu.h"
 #include "focus.h"
 #include "config.h"
 #include "gettext.h"
@@ -30,7 +31,7 @@
 
 #define MENU_NAME "client-list-combined-menu"
 
-ObMenu *combined_menu;
+static ObMenu *combined_menu;
 
 #define SEPARATOR -1
 #define ADD_DESKTOP -2
@@ -82,8 +83,6 @@ static gboolean self_update(ObMenuFrame *frame, gpointer data)
         }
 
         if (empty || onlyiconic) {
-            ObMenuEntry *e;
-
             /* no entries or only iconified windows, so add a
              * way to go to this desktop without uniconifying a window */
             if (!empty)
@@ -95,10 +94,12 @@ static gboolean self_update(ObMenuFrame *frame, gpointer data)
         }
     }
 
-    menu_add_separator(menu, SEPARATOR, _("Manage desktops"));
-    menu_add_normal(menu, ADD_DESKTOP, _("_Add new desktop"), NULL, TRUE);
-    menu_add_normal(menu, REMOVE_DESKTOP, _("_Remove last desktop"),
-                    NULL, TRUE);
+    if (config_menu_manage_desktops) {
+        menu_add_separator(menu, SEPARATOR, _("Manage desktops"));
+        menu_add_normal(menu, ADD_DESKTOP, _("_Add new desktop"), NULL, TRUE);
+        menu_add_normal(menu, REMOVE_DESKTOP, _("_Remove last desktop"),
+                        NULL, TRUE);
+    }
 
     return TRUE; /* always show the menu */
 }
