@@ -22,6 +22,7 @@
 #include "config.h"
 #include "screen.h"
 #include "client.h"
+#include "client_menu.h"
 #include "openbox.h"
 #include "frame.h"
 #include "moveresize.h"
@@ -352,7 +353,7 @@ static void client_menu_place(ObMenuFrame *frame, gint *x, gint *y,
     }
 }
 
-void client_menu_startup()
+void client_menu_startup(void)
 {
     ObMenu *menu;
     ObMenuEntry *e;
