@@ -39,10 +39,7 @@ struct _ObDock
     RrAppearance *a_frame;
 
     /* actual position (when not auto-hidden) */
-    gint x;
-    gint y;
-    gint w;
-    gint h;
+    Rect area;
 
     gboolean hidden;
 
@@ -82,4 +79,6 @@ void dock_remove(ObDockApp *app, gboolean reparent);
 void dock_app_drag(ObDockApp *app, XMotionEvent *e);
 void dock_app_configure(ObDockApp *app, gint w, gint h);
 
+void dock_get_area(Rect *a);
+
 #endif
