@@ -29,7 +29,7 @@
 #include "render/render.h"
 #include "render/theme.h"
 
-ObPopup *popup_new()
+ObPopup *popup_new(void)
 {
     XSetWindowAttributes attrib;
     ObPopup *self = g_new0(ObPopup, 1);
@@ -58,6 +58,7 @@ ObPopup *popup_new()
     XMapWindow(ob_display, self->text);
 
     stacking_add(INTERNAL_AS_WINDOW(self));
+    g_hash_table_insert(window_map, &self->bg, self);
     return self;
 }
 
@@ -68,6 +69,7 @@ void popup_free(ObPopup *self)
         XDestroyWindow(ob_display, self->text);
         RrAppearanceFree(self->a_bg);
         RrAppearanceFree(self->a_text);
+        g_hash_table_remove(window_map, &self->bg);
         stacking_remove(self);
         g_free(self);
     }
@@ -151,14 +153,12 @@ void popup_delay_show(ObPopup *self, gulong usec, gchar *text)
 {
     gint l, t, r, b;
     gint x, y, w, h;
+    guint m;
     gint emptyx, emptyy; /* empty space between elements */
     gint textx, texty, textw, texth;
     gint iconx, icony, iconw, iconh;
     Rect *area, mon;
 
-    RECT_SET(mon, self->x, self->y, 1, 1);
-    area = screen_physical_area_monitor(screen_find_monitor(&mon));
-
     /* when there is no icon and the text is not parent relative, then
        fill the whole dialog with the text appearance, don't use the bg at all
     */
@@ -246,8 +246,31 @@ void popup_delay_show(ObPopup *self, gulong usec, gchar *text)
         break;
     }
 
-    x=MAX(MIN(x, area->width-w),0);
-    y=MAX(MIN(y, area->height-h),0);
+    /* Find the monitor which contains the biggest part of the popup.
+     * If the popup is completely off screen, limit it to the intersection
+     * of all monitors and then try again. If it's still off screen, put it
+     * on monitor 0. */
+    RECT_SET(mon, x, y, w, h);
+    m = screen_find_monitor(&mon);
+    area = screen_physical_area_monitor(m);
+
+    x=MAX(MIN(x, area->x+area->width-w),area->x);
+    y=MAX(MIN(y, area->y+area->height-h),area->y);
+
+    g_free(area);
+
+    if (m == screen_num_monitors) {
+        RECT_SET(mon, x, y, w, h);
+        m = screen_find_monitor(&mon);
+        if (m == screen_num_monitors)
+            m = 0;
+        area = screen_physical_area_monitor(m);
+
+        x=MAX(MIN(x, area->x+area->width-w),area->x);
+        y=MAX(MIN(y, area->y+area->height-h),area->y);
+
+        g_free(area);
+    }
 
     /* set the windows/appearances up */
     XMoveResizeWindow(ob_display, self->bg, x, y, w, h);
@@ -282,8 +305,6 @@ void popup_delay_show(ObPopup *self, gulong usec, gchar *text)
             popup_show_timeout(self);
         }
     }
-
-    g_free(area);
 }
 
 void popup_hide(ObPopup *self)
@@ -315,12 +336,12 @@ static void icon_popup_draw_icon(gint x, gint y, gint w, gint h, gpointer data)
     RrPaint(self->a_icon, self->icon, w, h);
 }
 
-ObIconPopup *icon_popup_new()
+ObIconPopup *icon_popup_new(void)
 {
     ObIconPopup *self;
 
     self = g_new0(ObIconPopup, 1);
-    self->popup = popup_new(TRUE);
+    self->popup = popup_new();
     self->a_icon = RrAppearanceCopy(ob_rr_theme->a_clear_tex);
     self->icon = XCreateWindow(ob_display, self->popup->bg,
                                0, 0, 1, 1, 0,
@@ -473,12 +494,12 @@ static void pager_popup_draw_icon(gint px, gint py, gint w, gint h,
     }
 }
 
-ObPagerPopup *pager_popup_new()
+ObPagerPopup *pager_popup_new(void)
 {
     ObPagerPopup *self;
 
     self = g_new(ObPagerPopup, 1);
-    self->popup = popup_new(TRUE);
+    self->popup = popup_new();
 
     self->desks = 0;
     self->wins = g_new(Window, self->desks);
