@@ -20,11 +20,12 @@
 #ifndef __stacking_h
 #define __stacking_h
 
-#include "window.h"
-
 #include <glib.h>
 #include <X11/Xlib.h>
 
+struct _ObWindow;
+struct _ObClient;
+
 /*! The possible stacking layers a client window can be a part of */
 typedef enum {
     OB_STACKING_LAYER_INVALID,
@@ -44,21 +45,27 @@ extern GList *stacking_list;
   stacking_list */
 void stacking_set_list();
 
-void stacking_add(ObWindow *win);
-void stacking_add_nonintrusive(ObWindow *win);
+void stacking_add(struct _ObWindow *win);
+void stacking_add_nonintrusive(struct _ObWindow *win);
 #define stacking_remove(win) stacking_list = g_list_remove(stacking_list, win);
 
 /*! Raises a window above all others in its stacking layer */
-void stacking_raise(ObWindow *window);
+void stacking_raise(struct _ObWindow *window);
+
+/*! Temporarily raises a window above all others */
+void stacking_temp_raise(struct _ObWindow *window);
+
+/*! Restores any temporarily raised windows to their correct place */
+void stacking_restore();
 
 /*! Lowers a window below all others in its stacking layer */
-void stacking_lower(ObWindow *window);
+void stacking_lower(struct _ObWindow *window);
 
 /*! Moves a window below another if its in the same layer.
   This function does not enforce stacking rules IRT transients n such, and so
   it should really ONLY be used to restore stacking orders from saved sessions
 */
-void stacking_below(ObWindow *window, ObWindow *below);
+void stacking_below(struct _ObWindow *window, struct _ObWindow *below);
 
 /*! Restack a window based upon a sibling (or all windows) in various ways.
   @param client The client to be restacked
