@@ -25,7 +25,7 @@ gboolean translate_button(const gchar *str, guint *state, guint *keycode);
 gboolean translate_key(const gchar *str, guint *state, guint *keycode);
 
 /*! Give the string form of a keycode */
-const gchar *translate_keycode(guint keycode);
+gchar *translate_keycode(guint keycode);
 
 /*! Translate a keycode to the unicode character it represents */
 gunichar translate_unichar(guint keycode);
