@@ -115,7 +115,7 @@ RrTheme* RrThemeNew(const RrInstance *inst, const gchar *name,
     theme->a_menu_normal = RrAppearanceNew(inst, 0);
     theme->a_menu_selected = RrAppearanceNew(inst, 0);
     theme->a_menu_disabled = RrAppearanceNew(inst, 0);
-    theme->a_menu_disabled_selected = RrAppearanceNew(inst, 0);
+    /* a_menu_disabled_selected is copied from a_menu_selected */
     theme->a_menu_text_normal = RrAppearanceNew(inst, 1);
     theme->a_menu_text_selected = RrAppearanceNew(inst, 1);
     theme->a_menu_text_disabled = RrAppearanceNew(inst, 1);
@@ -543,21 +543,6 @@ RrTheme* RrThemeNew(const RrInstance *inst, const gchar *name,
                                        OB_DEFAULT_ICON_HEIGHT,
                                        OB_DEFAULT_ICON_pixel_data);
 
-    /* the toggled hover mask = the toggled unpressed mask (i.e. no change) */
-    theme->max_toggled_hover_mask =
-        RrPixmapMaskCopy(theme->max_toggled_mask);
-    theme->desk_toggled_hover_mask =
-        RrPixmapMaskCopy(theme->desk_toggled_mask);
-    theme->shade_toggled_hover_mask =
-        RrPixmapMaskCopy(theme->shade_toggled_mask);
-    /* the toggled pressed mask = the toggled unpressed mask (i.e. no change)*/
-    theme->max_toggled_pressed_mask =
-        RrPixmapMaskCopy(theme->max_toggled_mask);
-    theme->desk_toggled_pressed_mask =
-        RrPixmapMaskCopy(theme->desk_toggled_mask);
-    theme->shade_toggled_pressed_mask =
-        RrPixmapMaskCopy(theme->shade_toggled_mask);
-
     /* read the decoration textures */
     if (!read_appearance(db, inst,
                          "window.active.title.bg", theme->a_focused_title,
@@ -912,13 +897,9 @@ RrTheme* RrThemeNew(const RrInstance *inst, const gchar *name,
             j = (i > 0 ? 0 : 255);
             i = ABS(i*255/100);
 
-            theme->title_focused_shadow_color = RrColorNew(inst, j, j, j);
-            theme->title_focused_shadow_alpha = i;
             theme->osd_shadow_color = RrColorNew(inst, j, j, j);
             theme->osd_shadow_alpha = i;
         } else {
-            theme->title_focused_shadow_color = RrColorNew(inst, 0, 0, 0);
-            theme->title_focused_shadow_alpha = 50;
             theme->osd_shadow_color = RrColorNew(inst, 0, 0, 0);
             theme->osd_shadow_alpha = 50;
         }
@@ -1470,6 +1451,7 @@ void RrThemeFree(RrTheme *theme)
         RrFontClose(theme->win_font_unfocused);
         RrFontClose(theme->menu_title_font);
         RrFontClose(theme->menu_font);
+        RrFontClose(theme->osd_font);
 
         RrAppearanceFree(theme->a_disabled_focused_max);
         RrAppearanceFree(theme->a_disabled_unfocused_max);
